Template Tags
=============

We provide a few template tags to make it easier to render
captcha challenges as well as manually render your own challenge.


**get_sitekey()**

    Returns the site key for the currently active provider.

**get_challenge_class()**

    Returns the css class name for the currently active provider.

    This is used to automatically bind challenges to HTML elements.

**get_callback_name()**

    Return the Javascript callback function name for the currently
    active provider.

**render_challenge(challenge_type="visible", text="submit")**

    Renders the challenge.

    Visible challenges (example, Checkbox) as renders as divs.

    Invisible challenges are rendered as buttons.

    The ``text`` arguments specifies the text to use for buttons.

    You can override the kind of HTML generated by creating a template
    called ``challenge.html`` in the ``allcaptcha`` directory inside your
    global templates directory.
